@@ -3,6 +3,7 @@ import io
 import typing
 import numpy as np
 import cv2
+import numpy as np
 import pdf2image
 import time
 import pytesseract
@@ -10,6 +11,7 @@ import yaml
 import json
 import difflib
 import unidecode
+import matplotlib.pyplot as plt
 import PIL
 
 # print("Hello sheet music")
@@ -54,6 +56,7 @@ def textRecognizer(imagePath):
 	cv2.waitKey(0)
 
 def cropImage(img):
+	# findContentBox(img)
 	return img
 	return img[0:len(img)//2, 0:len(img[0])//2]
 
@@ -230,6 +233,73 @@ def predictParts(detectionData, instruments, imageWidth, imageHeight):
 			# Its probably a full score
 			return ["full score"], [["full score"]]
 
+# define a function which returns an image as numpy array from figure
+def get_img_from_pyplot_fig(dpi=180):
+    buf = io.BytesIO()
+    plt.savefig(buf, format="png", dpi=dpi)
+    buf.seek(0)
+    img_arr = np.frombuffer(buf.getvalue(), dtype=np.uint8)
+    buf.close()
+    img = cv2.imdecode(img_arr, 1)
+    img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
+    return img
+
+# Accepts an image matrix
+# Finds a bounding box for where the main content of the page most likely is
+def findContentBox(img):
+	# print("yo")
+	# print("hmm")
+	# print("test: ", test)
+	# img = np.array([[[255, 255, 255], [2, 3, 4]], [[255, 0, 0], [4, 5, 6]]])
+	img = np.average(img, axis=2)       # Convert to black-white
+	img = 255 - img
+	rows = np.average(img, axis=1)
+	cols = np.average(img, axis=0)
+	# x_min = np.percentile(img, 95, axis=1)  # Find 95th percentile of data
+	# x_max = np.percentile(img, 5, axis=1)  # Find 5th percentile of data
+	rows_hist, _ = np.histogram(np.arange(rows.shape[0]), weights=rows, bins=16, density=False)
+	cols_hist, _ = np.histogram(np.arange(cols.shape[0]), weights=cols, bins=32, density=False)
+	# img[:,:] = img[:,:,:]
+	print("img:\n", img)
+	# print("x:", x_min, x_max)
+	print("rows:", rows)
+	print("cols:", cols)
+	print("rows_hist:\n", rows_hist)
+	print("cols_hist:\n", cols_hist)
+	# print(img[2000, 1000, 1])
+	print("shape:", img.shape)
+
+	plt.clf()
+	plt.bar(np.arange(rows_hist.shape[0]), rows_hist)
+	histogram = get_img_from_pyplot_fig()
+	# buf = io.BytesIO()
+	# plt.savefig(buf, format="png", dpi=100)
+	# buf.seek(0)
+	# histogram = np.frombuffer(buf.getvalue(), dtype=np.uint8)
+	# print("hist 1:", histogram, histogram.shape[0])
+	# histogram = cv2.imdecode(histogram, cv2.IMREAD_UNCHANGED)
+	# buf.close()
+	# print("hist 2:", histogram)
+	# histogram = cv2.cvtColor(histogram, cv2.COLOR_BGR2RGB)
+	# print("hist 3:", histogram)
+
+	kernel = np.ones((200, 200), np.float32)/(200 * 200)
+	# img_filtered = cv2.filter2D(img, -1, kernel)
+	kernel_size = (np.array((img.shape[1], img.shape[0])) //6) * 2 + 1
+	img_filtered = cv2.GaussianBlur(img, kernel_size, 0)
+	img_filtered_rows = np.average(img_filtered, axis=1)
+	img_filtered_cols = np.average(img_filtered, axis=0)
+
+	plt.clf()
+	plt.plot(img_filtered_rows)
+	img_filtered_chart = get_img_from_pyplot_fig()
+
+	x = 0
+	y = 0
+	width = 0
+	height = 0
+
+	return x, y, width, height, histogram, 255 - 4 * img_filtered, img_filtered_chart
 
 def predict_parts_in_img(img : io.BytesIO | bytes | PIL.Image.Image, instruments, use_lstm=False, tessdata_dir=None) -> typing.Tuple[list, list]:
 	if type(img) is PIL.Image.Image:
